Package: factDesign
Title: Factorial designed microarray experiment analysis
Version: 1.88.0
Author: Denise Scholtens
Description: This package provides a set of tools for analyzing data
        from a factorial designed microarray experiment, or any
        microarray experiment for which a linear model is appropriate.
        The functions can be used to evaluate tests of contrast of
        biological interest and perform single outlier detection.
Depends: Biobase (>= 2.5.5)
Imports: stats
Suggests: affy, genefilter, multtest
Maintainer: Denise Scholtens <dscholtens@northwestern.edu>
License: LGPL
biocViews: Microarray, DifferentialExpression
git_url: https://git.bioconductor.org/packages/factDesign
git_branch: RELEASE_3_23
git_last_commit: 8221d18
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 22:02:01 UTC; biocbuild
